@@ -10,12 +10,14 @@ from .common import _preprocess
 from .common import _getSTAC
 from .common import _getDOI
 from .common import _getCitation
+from .common import _panSharpen
+from .common import _matchHistogram
 from .extending import extend
 
 
 @extend(ee.image.Image)
 def __getitem__(self, key):
-    '''Gets the band of the image according to the specified key.
+    """Gets the band of the image according to the specified key.
 
     Parameters
     ----------
@@ -29,8 +31,8 @@ def __getitem__(self, key):
     -------
     ee.Image
         Image with the selected bands.
-    '''
-    if isinstance(key,slice):
+    """
+    if isinstance(key, slice):
 
         if key.start == None:
             start = 0
@@ -42,7 +44,7 @@ def __getitem__(self, key):
         else:
             stop = key.stop
 
-        selected = self.slice(start,stop)
+        selected = self.slice(start, stop)
 
     else:
         selected = self.select(key)
@@ -929,7 +931,7 @@ def maskClouds(
             - 'qa' : Use Quality Assessment band.
         This parameter is ignored for Landsat products.
     prob : numeric [0, 100], default = 60
-        Cloud probability threshold. Valid just for method = 'prob'. This parameter is ignored for Landsat products.
+        Cloud probability threshold. Valid just for method = 'cloud_prob'. This parameter is ignored for Landsat products.
     maskCirrus : boolean, default = True
         Whether to mask cirrus clouds. Valid just for method = 'qa'. This parameter is ignored for Landsat products.
     maskShadows : boolean, default = True
@@ -1257,3 +1259,78 @@ def getCitation(self):
     [doi:10.5067/GPM/IMERG/3B-HH/06](https://doi.org/10.5067/GPM/IMERG/3B-HH/06)'
     """
     return _getCitation(self)
+
+
+@extend(ee.image.Image)
+def panSharpen(self, method="SFIM", qa=None, **kwargs):
+    """Apply panchromatic sharpening to the Image. Optionally, run quality assessments between the original and
+    sharpened Image to measure spectral distortion and set results as properties of the sharpened Image.
+
+    Parameters
+    ----------
+    self : ee.Image [this]
+        Image to sharpen.
+    method : str, default="SFIM"
+        The sharpening algorithm to apply. Current options are "SFIM" (Smoothing Filter-based Intensity Modulation),
+        "HPFA" (High Pass Filter Addition), "PCS" (Principal Component Substitution), and "SM" (simple mean). Different
+        sharpening methods will produce different quality sharpening results in different scenarios.
+    qa : str | list, default=None
+        One or more optional quality assessment names to apply after sharpening, e.g. "MSE", "RASE", "UIQI", etc.
+    **kwargs :
+        Keyword arguments passed to ee.Image.reduceRegion() such as "geometry", "maxPixels", "bestEffort", etc. These
+        arguments are only used for PCS sharpening and quality assessments.
+
+    Returns
+    -------
+    ee.Image
+        The Image with all sharpenable bands sharpened to the panchromatic resolution and quality assessments run and
+        set as properties.
+
+    Examples
+    --------
+    >>> import ee, eemont
+    >>> ee.Authenticate()
+    >>> ee.Initialize()
+    >>> source = ee.Image("LANDSAT/LC08/C01/T1_TOA/LC08_047027_20160819")
+    >>> sharp = source.panSharpen(method="HPFA", qa=["MSE", "RMSE"], maxPixels=1e13)
+    """
+    return _panSharpen(self, method, qa, **kwargs)
+
+
+@extend(ee.image.Image)
+def matchHistogram(self, target, bands, geometry=None, maxBuckets=256):
+    """Adjust the image's histogram to match a target image.
+
+    Parameters
+    ----------
+    self : ee.Image [this]
+        Image to adjust.
+    target : ee.Image
+        Image to match.
+    bands : dict
+        A dictionary of band names to match, with source bands as keys and target bands as values.
+    geometry : ee.Geometry, default=None
+        The region to match histograms in that overlaps both images. If none is provided, the geometry of the source image will be used.
+    maxBuckets : int, default=256
+        The maximum number of buckets to use when building histograms. Will be rounded to the nearest power of 2.
+
+    Returns
+    -------
+    ee.Image
+        The adjusted image containing the matched source bands.
+
+    Examples
+    --------
+    >>> import ee, eemont
+    >>> ee.Authenticate()
+    >>> ee.Initialize()
+    >>> source = ee.Image("LANDSAT/LC08/C01/T1_TOA/LC08_047027_20160819")
+    >>> target = ee.Image("LANDSAT/LE07/C01/T1_TOA/LE07_046027_20150701")
+    >>> bands = {
+    >>>    "B4": "B3",
+    >>>    "B3": "B2",
+    >>>    "B2": "B1"
+    >>> }
+    >>> matched = source.matchHistogram(target, bands)
+    """
+    return _matchHistogram(self, target, bands, geometry, maxBuckets)
