@@ -11,12 +11,13 @@ from .common import _preprocess
 from .common import _getSTAC
 from .common import _getDOI
 from .common import _getCitation
+from .common import _panSharpen
 from .extending import extend
 
 
 @extend(ee.imagecollection.ImageCollection)
 def __len__(self):
-    '''Returns the size of the image collection.
+    """Returns the size of the image collection.
 
     Parameters
     ----------
@@ -27,13 +28,13 @@ def __len__(self):
     -------
     int
         Size of the image collection.
-    '''
+    """
     return self.size().getInfo()
 
 
 @extend(ee.imagecollection.ImageCollection)
 def __getitem__(self, key):
-    '''Gets the band of each image in the image collection according to the specified key.
+    """Gets the band of each image in the image collection according to the specified key.
 
     Parameters
     ----------
@@ -47,8 +48,8 @@ def __getitem__(self, key):
     -------
     ee.ImageCollection
         Image Collection with the selected bands.
-    '''
-    if isinstance(key,slice):
+    """
+    if isinstance(key, slice):
 
         if key.start == None:
             start = 0
@@ -61,8 +62,8 @@ def __getitem__(self, key):
             stop = key.stop
 
         def sliceCollection(img):
-            return img.slice(start,stop)
-        
+            return img.slice(start, stop)
+
         selected = self.map(sliceCollection)
 
     else:
@@ -722,7 +723,7 @@ def maskClouds(
             - 'qa' : Use Quality Assessment band.
         This parameter is ignored for Landsat products.
     prob : numeric [0, 100], default = 60
-        Cloud probability threshold. Valid just for method = 'prob'. This parameter is ignored for Landsat products.
+        Cloud probability threshold. Valid just for method = 'cloud_prob'. This parameter is ignored for Landsat products.
     maskCirrus : boolean, default = True
         Whether to mask cirrus clouds. Valid just for method = 'qa'. This parameter is ignored for Landsat products.
     maskShadows : boolean, default = True
@@ -1051,3 +1052,40 @@ def getCitation(self):
     [doi:10.5067/GPM/IMERG/3B-HH/06](https://doi.org/10.5067/GPM/IMERG/3B-HH/06)'
     """
     return _getCitation(self)
+
+
+@extend(ee.imagecollection.ImageCollection)
+def panSharpen(self, method="SFIM", qa=None, **kwargs):
+    """Apply panchromatic sharpening to each Image in the Image Collection. Optionally, run quality assessments between
+    the original and sharpened Images to measure spectral distortion and set results as properties of each sharpened
+    Image.
+
+    Parameters
+    ----------
+    self : ee.ImageCollection [this]
+        Image Collection to sharpen.
+    method : str, default="SFIM"
+        The sharpening algorithm to apply. Current options are "SFIM" (Smoothing Filter-based Intensity Modulation),
+        "HPFA" (High Pass Filter Addition), "PCS" (Principal Component Substitution), and "SM" (simple mean). Different
+        sharpening methods will produce different quality sharpening results in different scenarios.
+    qa : str | list, default=None
+        One or more optional quality assessment names to apply after sharpening, e.g. "MSE", "RASE", "UIQI", etc.
+    **kwargs :
+        Keyword arguments passed to ee.Image.reduceRegion() such as "geometry", "maxPixels", "bestEffort", etc. These
+        arguments are only used for PCS sharpening and quality assessments.
+
+    Returns
+    -------
+    ee.ImageCollection
+        The Image Collection with all sharpenable bands sharpened to the panchromatic resolution and quality assessments
+        run and set as properties.
+
+    Examples
+    --------
+    >>> import ee, eemont
+    >>> ee.Authenticate()
+    >>> ee.Initialize()
+    >>> source = ee.ImageCollection("LANDSAT/LC08/C01/T1_TOA")
+    >>> sharp = source.panSharpen(method="HPFA", qa=["MSE", "RMSE"], maxPixels=1e13)
+    """
+    return _panSharpen(self, method, qa, **kwargs)
